part of masamune_local_messaging;

@immutable
class LocalMessagingAdapter extends MessagingAdapter<MessagingValue> {
  const LocalMessagingAdapter({
    this.androidDefaultIcon = "@mipmap/ic_launcher",
    this.androidChannelId = "defaultChannel",
    this.androidChannelName = "Default Channel",
  });

  final String androidDefaultIcon;
  final String androidChannelId;
  final String androidChannelName;

  @override
  Future<void> initialize(
    BuildContext context, {
    List<void Function(MessagingValue message)> callback = const [],
    List<String> subscribe = const [],
  }) async {
    await _initialize(context);
  }

  @override
  Future<void> send({
    required String title,
    required String text,
    required String topic,
    String? path,
    DynamicMap? data,
  }) async {
    await LocalMessagingCore.send(
      title: title,
      text: text,
      topic: topic,
      androidChannelId: androidChannelId,
      androidChannelName: androidChannelName,
    );
  }

  @override
  Future<void> schedule({
    required String title,
    required String text,
    required String topic,
    required DateTime dateTime,
    String? path,
    DynamicMap? data,
    MessagingScheduleRepeatType repeatType = MessagingScheduleRepeatType.none,
  }) async {
    await LocalMessagingCore.schedule(
      title: title,
      text: text,
      topic: topic,
      dateTime: dateTime,
      repeatType: repeatType,
      androidChannelId: androidChannelId,
      androidChannelName: androidChannelName,
    );
  }

  @override
  @mustCallSuper
  Future<void> onAfterFinishBoot(BuildContext context) async {
    await _initialize(context);
    return super.onAfterFinishBoot(context);
  }

  Future<void> _initialize(BuildContext context) async {
    await LocalMessagingCore.initialize(
      androidDefaultIcon: androidDefaultIcon,
    );
  }

  @override
  void listen(void Function(MessagingValue messaging) callback) {
    throw UnimplementedError();
  }

  @override
  void subscribe(String topic) {
    throw UnimplementedError();
  }

  @override
  void unlisten(void Function(MessagingValue messaging) callback) {
    throw UnimplementedError();
  }

  @override
  void unsubscribe(String topic) {
    throw UnimplementedError();
  }

  @override
  Future<void> cancelAllSchedule() {
    return LocalMessagingCore.cancelAllSchedule();
  }

  @override
  Future<void> cancelSchedule(String topic) {
    return LocalMessagingCore.cancelSchedule(topic);
  }
}
